@@ -40,7 +40,7 @@ type ('a,'b) decoder =
     name : string;
     info : unit -> 'a*metadata;
     decode : ('b -> unit) -> unit ;
-    restart : Ogg.Stream.t -> unit ;
+    restart : Ogg.Stream.stream -> unit ;
     samples_of_granulepos : Int64.t -> Int64.t }
 type audio_info = 
   { channels : int;
@@ -90,7 +90,7 @@ type index_element =
     total_samples : Int64.t }
 
 type stream = 
-  { mutable os : Ogg.Stream.t;
+  { mutable os : Ogg.Stream.stream;
     mutable position : float;
     index : (Int64.t,index_element) Hashtbl.t;
     mutable read_samples : Int64.t;
@@ -111,7 +111,7 @@ type track =
   Video_track of (string*nativeint)
 
 exception Internal of (Ogg.Page.t*(int option))
-exception Exit of nativeint*Ogg.Stream.t*decoders
+exception Exit of nativeint*Ogg.Stream.stream*decoders
 exception Track of (bool*nativeint*stream)
 exception Invalid_stream
 exception Not_available
@@ -123,7 +123,7 @@ exception Not_available
 exception End_of_stream
 
 type register_decoder =
-  (Ogg.Stream.packet -> bool) * (Ogg.Stream.t -> decoders)
+  (Ogg.Stream.packet -> bool) * (Ogg.Stream.stream -> decoders)
 
 let get_some x = 
   match x with
@@ -307,9 +307,9 @@ let init ?(log=(fun _ -> ())) c =
 let unix_callbacks fd = 
   { read = 
       (fun len ->
-        let buf = String.create len in
+        let buf = Bytes.create len in
         let ret = Unix.read fd buf 0 len in
-        buf,ret);
+        Bytes.to_string buf,ret);
     tell = Some (fun () -> Unix.lseek fd 0 Unix.SEEK_CUR);
     seek = Some (fun len -> Unix.lseek fd len Unix.SEEK_SET) }
 
@@ -338,9 +338,9 @@ let fold_tracks dec f x =
 let get_track dec dtype =
   let test ended id stream =
     match stream.dec,dtype with
-      | Audio d,Audio_track (_,x) when x = id -> 
+      | Audio _,Audio_track (_,x) when x = id -> 
           raise (Track (ended,id,stream))
-      | Video d,Video_track (_,x) when x = id -> 
+      | Video _,Video_track (_,x) when x = id -> 
           raise (Track (ended,id,stream))
       | _ -> ()
   in
@@ -368,10 +368,10 @@ type standard_tracks =
 
 let drop_track dec dtype =
   (* Remove all track of this type *)
-  let rec get_tracks id s l =
+  let get_tracks id s l =
     match s.dec,dtype with
-      | Audio d,Audio_track (_,x) when x = id -> (id,s)::l
-      | Video d,Video_track (_,x) when x = id -> (id,s)::l
+      | Audio _,Audio_track (_,x) when x = id -> (id,s)::l
+      | Video _,Video_track (_,x) when x = id -> (id,s)::l
       | _ -> l
   in
   let tracks = fold_tracks dec get_tracks [] in
@@ -593,7 +593,7 @@ let seek ?(relative=false) dec time =
       float x /. float y
     in
     match stream.dec with
-      | Audio d -> 
+      | Audio _ -> 
             { sync_id    = id;
               sync_stream = stream;
               sync_rate  = sample_rate ();
@@ -601,7 +601,7 @@ let seek ?(relative=false) dec time =
               sync_granulepos = Int64.zero;
               sync_skip_samples = 0;
               sync_bytes = 0 } :: l
-      | Video d -> 
+      | Video _ -> 
             { sync_id    = id;
               sync_stream = stream;
               sync_rate  = sample_rate ();
